==> mpqc_2.0.4.orig.tar.gz: mpqc-2.0.4.orig/src/lib/util/ref/identity.cc <==
//
// identity.cc
//
// Copyright (C) 1996 Limit Point Systems, Inc.
//
// Author: Curtis Janssen <cljanss@limitpt.com>
// Maintainer: LPS
//
// This file is part of the SC Toolkit.
//
// The SC Toolkit is free software; you can redistribute it and/or modify
// it under the terms of the GNU Library General Public License as published by
// the Free Software Foundation; either version 2, or (at your option)
// any later version.
//
// The SC Toolkit is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU Library General Public License for more details.
//
// You should have received a copy of the GNU Library General Public License
// along with the SC Toolkit; see the file COPYING.LIB.  If not, write to
// the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
//
// The U.S. Government is granted a limited license as per AL 91-7.
//

#ifdef __GNUG__
#pragma implementation
#endif

#include <util/ref/identity.h>

using namespace std;

//////////////////////////////////////////////////////////////////////////

void
Identifier::print(ostream &o) const
{
  o << (unsigned long) id;
}

ostream &
operator << (ostream &o, const Identifier &i)
{
  i.print(o);
  return o;
}

//////////////////////////////////////////////////////////////////////////

Identity::~Identity()
{
}

//////////////////////////////////////////////////////////////////////////

==> mpqc_2.3.1.orig.tar.gz: mpqc-2.3.1/src/lib/util/ref/identity.cc <==
//
// identity.cc
//
// Copyright (C) 1996 Limit Point Systems, Inc.
//
// Author: Curtis Janssen <cljanss@limitpt.com>
// Maintainer: LPS
//
// This file is part of the SC Toolkit.
//
// The SC Toolkit is free software; you can redistribute it and/or modify
// it under the terms of the GNU Library General Public License as published by
// the Free Software Foundation; either version 2, or (at your option)
// any later version.
//
// The SC Toolkit is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU Library General Public License for more details.
//
// You should have received a copy of the GNU Library General Public License
// along with the SC Toolkit; see the file COPYING.LIB.  If not, write to
// the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
//
// The U.S. Government is granted a limited license as per AL 91-7.
//

#ifdef __GNUG__
#pragma implementation
#endif

#include <util/ref/identity.h>

using namespace std;
using namespace sc;

//////////////////////////////////////////////////////////////////////////

void
Identifier::print(ostream &o) const
{
  o << (unsigned long) id;
}

ostream &
sc::operator << (ostream &o, const Identifier &i)
{
  i.print(o);
  return o;
}

//////////////////////////////////////////////////////////////////////////

Identity::~Identity()
{
}

//////////////////////////////////////////////////////////////////////////
